@@ -6,7 +6,7 @@ require 5.006;
 use strict;
 use Carp;
 use warnings;
-our $VERSION = '1.5';
+our $VERSION = '1.6';
 
 sub new {
     my $self = shift->SUPER::new(@_);
@@ -15,6 +15,11 @@ sub new {
     return $self;
 }
 
+sub as_string {
+    my $self = shift;
+    return $self->_headers_as_string."\r\n".$self->body_raw;
+}
+
 sub parts {
     my $self = shift;
     if (!$self->{parts}) { $self->fill_parts }
